diff --git a/pressure-vessel/runtime.c b/pressure-vessel/runtime.c
index aa05c9e24a5ace4dbc36baf9489e218b915e4bca..bd119e12c46835988b144ba8f7f593be241fd1f5 100644
--- a/pressure-vessel/runtime.c
+++ b/pressure-vessel/runtime.c
@@ -7858,9 +7858,10 @@ pv_runtime_bind (PvRuntime *self,
             {
               const char *dir = search_path[j];
 
-              /* We are mounting our own runtime over /usr anyway, so
-               * ignore those */
-              if (flatpak_has_path_prefix (dir, "/usr"))
+              /* We are mounting our own runtime over /etc and /usr anyway,
+               * so ignore those */
+              if (flatpak_has_path_prefix (dir, "/usr")
+                  || flatpak_has_path_prefix (dir, "/etc"))
                 continue;
 
               /* Otherwise, if the directory exists, mask it */